===================================================
``psyclone.psyir.nodes.array_of_structures_member``
===================================================

.. automodule:: psyclone.psyir.nodes.array_of_structures_member

   .. contents::
      :local:

.. currentmodule:: psyclone.psyir.nodes.array_of_structures_member


Classes
=======

- :py:class:`ArrayOfStructuresMember`:
  Node representing a membership expression of a parent structure where the


.. autoclass:: ArrayOfStructuresMember
   :members:

   .. rubric:: Inheritance
   .. inheritance-diagram:: ArrayOfStructuresMember
      :parts: 1
